//! Common types used by the CDK.
//!
//! This crate is meant to be used by the CDK and other crates that need to interact with the CDK,
//! to store all the common types and traits, to avoid circular dependencies, and to make it easier
//! to extend the CDK, or build similar crates.

use bitcoin::secp256k1::{rand, All, Secp256k1};
use once_cell::sync::Lazy;

mod amount;
pub mod cdk_database;
pub mod dhke;
pub mod hex;
pub mod mint;
pub mod mint_url;
pub mod nuts;
pub mod secret;

/// Secp256k1 global context
pub static SECP256K1: Lazy<Secp256k1<All>> = Lazy::new(|| {
    let mut ctx = Secp256k1::new();
    let mut rng = rand::thread_rng();
    ctx.randomize(&mut rng);
    ctx
});

#[doc(hidden)]
pub use lightning_invoice::{self, Bolt11Invoice};

pub use self::{amount::Amount, mint_url::MintUrl, nuts::*, secret::Secret};
